pysnail.pysnail API documentation

# pysnail.pysnail

Core module of pysnail package.

View Source

     1"""Core module of pysnail package."""
     2import asyncio
     3import math
     4
     5
     6async def get_regular_snail() -> str:
     7  """
     8  A regular snail is on it's way to you.
     9  :return: returns a flavored markdown snail
    10  """
    11  await asyncio.sleep(10)
    12  return ':snail:'
    13
    14
    15async def get_blazingly_fast_snail() -> str:
    16  """A blazingly fast snail is on it's way to you.
    17
    18  Hint: you'd better not wait for this snail :)
    19  """
    20  await asyncio.sleep(math.inf)
    21  return ':snail:'

async def get_regular_snail() -> str: View Source

     7async def get_regular_snail() -> str:
     8  """
     9  A regular snail is on it's way to you.
    10  :return: returns a flavored markdown snail
    11  """
    12  await asyncio.sleep(10)
    13  return ':snail:'

A regular snail is on it's way to you.

###### Returns

> returns a flavored markdown snail

async def get_blazingly_fast_snail() -> str: View Source

    16async def get_blazingly_fast_snail() -> str:
    17  """A blazingly fast snail is on it's way to you.
    18
    19  Hint: you'd better not wait for this snail :)
    20  """
    21  await asyncio.sleep(math.inf)
    22  return ':snail:'

A blazingly fast snail is on it's way to you.

Hint: you'd better not wait for this snail :)